`pycountry-convert` is written and maintained by many contributors.

pycountry-convert: Authors
````````````````````````````

We'd like to thank the following people who have contributed to the `pycountry-convert` repository.

- Ian Molee <ian@tune.com>
- Ohad Lahav <ohad@tune.com>
- Jeff Tanner <jefft@tune.com>
